@@ -1,7 +1,7 @@
-from utils.utils import choose_random
+from perfect_information_game.utils import choose_random
 from time import sleep
 import numpy as np
-from move_selection.move_chooser import MoveChooser
+from perfect_information_game.move_selection import MoveChooser
 
 
 class RandomMoveChooser(MoveChooser):
